@@ -139,6 +139,7 @@ rcL.trans <- function(tab, nd=1, symmetric=FALSE, diagonal=c("none", "heterogene
                 else c("rcL.trans", "rcL", "assocmod")
   class(model) <- c(newclasses, class(model))
 
+  model$call.gnm <- model$call
   model$call <- match.call()
 
   model$assoc <- assoc(model, weighting=weighting)
@@ -180,7 +181,7 @@ assoc.rcL.trans <- function(model, weighting=c("marginal", "uniform", "none"), .
   nc <- ncol(tab)
   nl <- dim(tab)[3]
 
-  # Weight with marginal frequencies, cf. Becker & Clogg (1994), p. 83-84, and Becker & Clogg (1989), p. 144.
+  # Weight with marginal frequencies, cf. Clogg & Shihadeh (1994), p. 83-84, and Becker & Clogg (1989), p. 144.
   weighting <- match.arg(weighting)
   if(weighting == "marginal") {
       rp <- prop.table(apply(tab, 1, sum, na.rm=TRUE))
@@ -345,7 +346,8 @@ assoc.rcL.trans <- function(model, weighting=c("marginal", "uniform", "none"), .
   col.weights <- apply(tab, c(2, 3), sum, na.rm=TRUE)
 
   obj <- list(phi = layer, row = row, col = col, diagonal = dg,
-              weighting = weighting, row.weights = row.weights, col.weights = col.weights)
+              weighting = weighting, row.weights = row.weights, col.weights = col.weights,
+              vars = vars)
 
   class(obj) <- c("assoc.rcL.trans", "assoc.rcL", "assoc")
   obj
@@ -365,7 +367,7 @@ assoc.rcL.trans.symm <- function(model, weighting=c("marginal", "uniform", "none
 
   stopifnot(nr == nc)
 
-  # Weight with marginal frequencies, cf. Becker & Clogg (1994), p. 83-84, and Becker & Clogg (1989), p. 144.
+  # Weight with marginal frequencies, cf. Clogg & Shihadeh (1994), p. 83-84, and Becker & Clogg (1989), p. 144.
   weighting <- match.arg(weighting)
   if(weighting == "marginal")
       p <- prop.table(apply(tab, 1, sum, na.rm=TRUE) + apply(tab, 2, sum, na.rm=TRUE))
